Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: remoting/client/chromoting_view.h

Issue 2861047: Refactor the client code. Move all x11-related code into X11View and create... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/chromoting_view.h
===================================================================
--- remoting/client/chromoting_view.h (revision 52921)
+++ remoting/client/chromoting_view.h (working copy)
@@ -18,6 +18,12 @@
public:
virtual ~ChromotingView() {}
+ // Initialize the common structures for the view.
+ virtual bool Initialize() = 0;
+
+ // Free up resources allocated by this view.
+ virtual void TearDown() = 0;
+
// Tells the ChromotingView to paint the current image on the screen.
// TODO(hclam): Add rects as parameter if needed.
virtual void Paint() = 0;
@@ -34,12 +40,11 @@
// extends past the end of the backing store, it is filled with black.
virtual void SetViewport(int x, int y, int width, int height) = 0;
// Resize the underlying image that is displayed. This should match the size
// of the output from the decoder.
//
- // TODO(ajwong): We need a better name. Look at how Java represents this
- // stuff?
- virtual void SetBackingStoreSize(int width, int height) = 0;
+ // TODO(garykac): This handles only 1 screen. We need multi-screen support.
+ virtual void SetHostScreenSize(int width, int height) = 0;
// Handle the BeginUpdateStream message.
virtual void HandleBeginUpdateStream(HostMessage* msg) = 0;
Property changes on: remoting/client/chromoting_view.h
___________________________________________________________________
Added: svn:eol-style
+ LF

Powered by Google App Engine
This is Rietveld 408576698
@@ -34,12 +40,11 @@
// extends past the end of the backing store, it is filled with black.
virtual void SetViewport(int x, int y, int width, int height) = 0;
- // Resize the underlying image that is displayed. This should match the size
- // of the output from the decoder.
+ // Resize the underlying image that contains the host screen buffer.
+ // This should match the size of the output from the decoder.
//